# tri-again

[![version](https://img.shields.io/pypi/v/tri-again?style=flat-square)][pypi]
[![python versions](https://img.shields.io/pypi/pyversions/tri-again?style=flat-square)][pypi]
[![license](https://img.shields.io/pypi/l/tri-again?style=flat-square)][pypi]
[![coverage](https://img.shields.io/badge/coverage-100%25-brightgreen?style=flat-square)][coverage]
[![build](https://img.shields.io/circleci/project/github/lace/tri-again/master?style=flat-square)][build]
[![code style](https://img.shields.io/badge/code%20style-black-black?style=flat-square)][black]

Simple scenegraph for quickly debugging 3D meshes, polylines, and points.

[pypi]: https://pypi.org/project/tri-again/
[coverage]: https://github.com/lace/tri-again/blob/master/.coveragerc#L2
[build]: https://circleci.com/gh/lace/tri-again/tree/master
[docs build]: https://tri-again.readthedocs.io/en/latest/
[black]: https://black.readthedocs.io/en/stable/

## Contribute

- Issue Tracker: https://github.com/lace/tri-again/issues
- Source Code: https://github.com/lace/tri-again

Pull requests welcome!


## Support

If you are having issues, please let us know.


## License

The project is licensed under the MIT license.
